@@ -49,7 +49,7 @@ usage of the functional interface to the L<String::Downgrade::Amharic> package.
 
 =head1 AUTHOR
 
-Daniel Yacob Mekonnen,  L<Yacob@EthiopiaOnline.Net|mailto:Yacob@EthiopiaOnline.Net>
+Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
 =head1 SEE ALSO
 
